==> ace_6.4.5+dfsg.orig.tar.gz: ace-6.4.5+dfsg.orig/ace/ETCL/ETCL_Constraint_Visitor.cpp <==
// -*- C++ -*-
//=============================================================================
/**
 * @file ETCL_Constraint_Visitor.cpp
 *
 * @author Jeff Parsons <j.parsons@vanderbilt.edu>
 */
//=============================================================================

#include "ace/ETCL/ETCL_Constraint_Visitor.h"

ACE_BEGIN_VERSIONED_NAMESPACE_DECL

ETCL_Constraint_Visitor::ETCL_Constraint_Visitor (void)
{
}

ETCL_Constraint_Visitor::~ETCL_Constraint_Visitor (void)
{
}

int
ETCL_Constraint_Visitor::visit_literal (ETCL_Literal_Constraint *)
{
  return 0;
}

int
ETCL_Constraint_Visitor::visit_identifier (ETCL_Identifier *)
{
  return 0;
}

int
ETCL_Constraint_Visitor::visit_union_value (ETCL_Union_Value *)
{
  return 0;
}

int
ETCL_Constraint_Visitor::visit_union_pos (ETCL_Union_Pos *)
{
  return 0;
}

int
ETCL_Constraint_Visitor::visit_component_pos (ETCL_Component_Pos *)
{
  return 0;
}

int
ETCL_Constraint_Visitor::visit_component_assoc (ETCL_Component_Assoc *)
{
  return 0;
}

int
ETCL_Constraint_Visitor::visit_component_array (ETCL_Component_Array *)
{
  return 0;
}

int
ETCL_Constraint_Visitor::visit_special (ETCL_Special *)
{
  return 0;
}

int
ETCL_Constraint_Visitor::visit_component (ETCL_Component *)
{
  return 0;
}

int
ETCL_Constraint_Visitor::visit_dot (ETCL_Dot *)
{
  return 0;
}

int
ETCL_Constraint_Visitor::visit_eval (ETCL_Eval *)
{
  return 0;
}

int
ETCL_Constraint_Visitor::visit_default (ETCL_Default *)
{
  return 0;
}

int
ETCL_Constraint_Visitor::visit_exist (ETCL_Exist *)
{
  return 0;
}

int
ETCL_Constraint_Visitor::visit_unary_expr (ETCL_Unary_Expr *)
{
  return 0;
}

int
ETCL_Constraint_Visitor::visit_binary_expr (ETCL_Binary_Expr *)
{
  return 0;
}

int
ETCL_Constraint_Visitor::visit_preference (ETCL_Preference *)
{
  return 0;
}

ACE_END_VERSIONED_NAMESPACE_DECL

==> ace_8.0.2+dfsg.orig.tar.gz: ace-8.0.2+dfsg.orig/ace/ETCL/ETCL_Constraint_Visitor.cpp <==
// -*- C++ -*-
//=============================================================================
/**
 * @file ETCL_Constraint_Visitor.cpp
 *
 * @author Jeff Parsons <j.parsons@vanderbilt.edu>
 */
//=============================================================================

#include "ace/ETCL/ETCL_Constraint_Visitor.h"

ACE_BEGIN_VERSIONED_NAMESPACE_DECL

ETCL_Constraint_Visitor::ETCL_Constraint_Visitor ()
{
}

ETCL_Constraint_Visitor::~ETCL_Constraint_Visitor ()
{
}

int
ETCL_Constraint_Visitor::visit_literal (ETCL_Literal_Constraint *)
{
  return 0;
}

int
ETCL_Constraint_Visitor::visit_identifier (ETCL_Identifier *)
{
  return 0;
}

int
ETCL_Constraint_Visitor::visit_union_value (ETCL_Union_Value *)
{
  return 0;
}

int
ETCL_Constraint_Visitor::visit_union_pos (ETCL_Union_Pos *)
{
  return 0;
}

int
ETCL_Constraint_Visitor::visit_component_pos (ETCL_Component_Pos *)
{
  return 0;
}

int
ETCL_Constraint_Visitor::visit_component_assoc (ETCL_Component_Assoc *)
{
  return 0;
}

int
ETCL_Constraint_Visitor::visit_component_array (ETCL_Component_Array *)
{
  return 0;
}

int
ETCL_Constraint_Visitor::visit_special (ETCL_Special *)
{
  return 0;
}

int
ETCL_Constraint_Visitor::visit_component (ETCL_Component *)
{
  return 0;
}

int
ETCL_Constraint_Visitor::visit_dot (ETCL_Dot *)
{
  return 0;
}

int
ETCL_Constraint_Visitor::visit_eval (ETCL_Eval *)
{
  return 0;
}

int
ETCL_Constraint_Visitor::visit_default (ETCL_Default *)
{
  return 0;
}

int
ETCL_Constraint_Visitor::visit_exist (ETCL_Exist *)
{
  return 0;
}

int
ETCL_Constraint_Visitor::visit_unary_expr (ETCL_Unary_Expr *)
{
  return 0;
}

int
ETCL_Constraint_Visitor::visit_binary_expr (ETCL_Binary_Expr *)
{
  return 0;
}

int
ETCL_Constraint_Visitor::visit_preference (ETCL_Preference *)
{
  return 0;
}

ACE_END_VERSIONED_NAMESPACE_DECL
